r'''
# `aws_odb_network`

Refer to the Terraform Registry for docs: [`aws_odb_network`](https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network).
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from .._jsii import *

import cdktn as _cdktn_78ede62e
import constructs as _constructs_77d1e7e8


class OdbNetwork(
    _cdktn_78ede62e.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetwork",
):
    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network aws_odb_network}.'''

    def __init__(
        self,
        scope: "_constructs_77d1e7e8.Construct",
        id: builtins.str,
        *,
        availability_zone_id: builtins.str,
        backup_subnet_cidr: builtins.str,
        client_subnet_cidr: builtins.str,
        display_name: builtins.str,
        s3_access: builtins.str,
        zero_etl_access: builtins.str,
        availability_zone: typing.Optional[builtins.str] = None,
        custom_domain_name: typing.Optional[builtins.str] = None,
        default_dns_prefix: typing.Optional[builtins.str] = None,
        delete_associated_resources: typing.Optional[typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"]] = None,
        kms_access: typing.Optional[builtins.str] = None,
        kms_policy_document: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        s3_policy_document: typing.Optional[builtins.str] = None,
        sts_access: typing.Optional[builtins.str] = None,
        sts_policy_document: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional[typing.Union["OdbNetworkTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
        connection: typing.Optional[typing.Union[typing.Union["_cdktn_78ede62e.SSHProvisionerConnection", typing.Dict[builtins.str, typing.Any]], typing.Union["_cdktn_78ede62e.WinrmProvisionerConnection", typing.Dict[builtins.str, typing.Any]]]] = None,
        count: typing.Optional[typing.Union[jsii.Number, "_cdktn_78ede62e.TerraformCount"]] = None,
        depends_on: typing.Optional[typing.Sequence["_cdktn_78ede62e.ITerraformDependable"]] = None,
        for_each: typing.Optional["_cdktn_78ede62e.ITerraformIterator"] = None,
        lifecycle: typing.Optional[typing.Union["_cdktn_78ede62e.TerraformResourceLifecycle", typing.Dict[builtins.str, typing.Any]]] = None,
        provider: typing.Optional["_cdktn_78ede62e.TerraformProvider"] = None,
        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union["_cdktn_78ede62e.FileProvisioner", typing.Dict[builtins.str, typing.Any]], typing.Union["_cdktn_78ede62e.LocalExecProvisioner", typing.Dict[builtins.str, typing.Any]], typing.Union["_cdktn_78ede62e.RemoteExecProvisioner", typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network aws_odb_network} Resource.

        :param scope: The scope in which to define this construct.
        :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param availability_zone_id: The AZ ID of the AZ where the ODB network is located. Changing this will force terraform to create new resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#availability_zone_id OdbNetwork#availability_zone_id}
        :param backup_subnet_cidr: The CIDR range of the backup subnet for the ODB network. Changing this will force terraform to create new resource. Constraints: - Must not overlap with the CIDR range of the client subnet. - Must not overlap with the CIDR ranges of the VPCs that are connected to the ODB network. - Must not use the following CIDR ranges that are reserved by OCI: - 100.106.0.0/16 and 100.107.0.0/16 - 169.254.0.0/16 - 224.0.0.0 - 239.255.255.255 - 240.0.0.0 - 255.255.255.255 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#backup_subnet_cidr OdbNetwork#backup_subnet_cidr}
        :param client_subnet_cidr: The CIDR notation for the network resource. Changing this will force terraform to create new resource. Constraints: - Must not overlap with the CIDR range of the backup subnet. - Must not overlap with the CIDR ranges of the VPCs that are connected to the ODB network. - Must not use the following CIDR ranges that are reserved by OCI: - 100.106.0.0/16 and 100.107.0.0/16 - 169.254.0.0/16 - 224.0.0.0 - 239.255.255.255 - 240.0.0.0 - 255.255.255.255 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#client_subnet_cidr OdbNetwork#client_subnet_cidr}
        :param display_name: The user-friendly name for the odb network. Changing this will force terraform to create a new resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#display_name OdbNetwork#display_name}
        :param s3_access: Specifies the configuration for Amazon S3 access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#s3_access OdbNetwork#s3_access}
        :param zero_etl_access: Specifies the configuration for Zero-ETL access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#zero_etl_access OdbNetwork#zero_etl_access}
        :param availability_zone: The name of the Availability Zone (AZ) where the odb network is located. Changing this will force terraform to create new resource Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#availability_zone OdbNetwork#availability_zone}
        :param custom_domain_name: The name of the custom domain that the network is located. custom_domain_name and default_dns_prefix both can't be given. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#custom_domain_name OdbNetwork#custom_domain_name}
        :param default_dns_prefix: The default DNS prefix for the network resource. Changing this will force terraform to create new resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#default_dns_prefix OdbNetwork#default_dns_prefix}
        :param delete_associated_resources: If set to true deletes associated OCI resources. Default false. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#delete_associated_resources OdbNetwork#delete_associated_resources}
        :param kms_access: Specifies the configuration for Amazon KMS access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#kms_access OdbNetwork#kms_access}
        :param kms_policy_document: Specifies the endpoint policy for Amazon KMS access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#kms_policy_document OdbNetwork#kms_policy_document}
        :param region: Region where this resource will be `managed <https://docs.aws.amazon.com/general/latest/gr/rande.html#regional-endpoints>`_. Defaults to the Region set in the `provider configuration <https://registry.terraform.io/providers/hashicorp/aws/latest/docs#aws-configuration-reference>`_. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#region OdbNetwork#region}
        :param s3_policy_document: Specifies the endpoint policy for Amazon S3 access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#s3_policy_document OdbNetwork#s3_policy_document}
        :param sts_access: Specifies the configuration for Amazon STS access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#sts_access OdbNetwork#sts_access}
        :param sts_policy_document: Specifies the endpoint policy for Amazon STS access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#sts_policy_document OdbNetwork#sts_policy_document}
        :param tags: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#tags OdbNetwork#tags}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#timeouts OdbNetwork#timeouts}
        :param connection: 
        :param count: 
        :param depends_on: 
        :param for_each: 
        :param lifecycle: 
        :param provider: 
        :param provisioners: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e41518babc6df2c1e4d7b0891415cabda8373c6f45f37933db537b1212cb9db6)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        config = OdbNetworkConfig(
            availability_zone_id=availability_zone_id,
            backup_subnet_cidr=backup_subnet_cidr,
            client_subnet_cidr=client_subnet_cidr,
            display_name=display_name,
            s3_access=s3_access,
            zero_etl_access=zero_etl_access,
            availability_zone=availability_zone,
            custom_domain_name=custom_domain_name,
            default_dns_prefix=default_dns_prefix,
            delete_associated_resources=delete_associated_resources,
            kms_access=kms_access,
            kms_policy_document=kms_policy_document,
            region=region,
            s3_policy_document=s3_policy_document,
            sts_access=sts_access,
            sts_policy_document=sts_policy_document,
            tags=tags,
            timeouts=timeouts,
            connection=connection,
            count=count,
            depends_on=depends_on,
            for_each=for_each,
            lifecycle=lifecycle,
            provider=provider,
            provisioners=provisioners,
        )

        jsii.create(self.__class__, self, [scope, id, config])

    @jsii.member(jsii_name="generateConfigForImport")
    @builtins.classmethod
    def generate_config_for_import(
        cls,
        scope: "_constructs_77d1e7e8.Construct",
        import_to_id: builtins.str,
        import_from_id: builtins.str,
        provider: typing.Optional["_cdktn_78ede62e.TerraformProvider"] = None,
    ) -> "_cdktn_78ede62e.ImportableResource":
        '''Generates CDKTN code for importing a OdbNetwork resource upon running "cdktn plan ".

        :param scope: The scope in which to define this construct.
        :param import_to_id: The construct id used in the generated config for the OdbNetwork to import.
        :param import_from_id: The id of the existing OdbNetwork that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#import import section} in the documentation of this resource for the id to use
        :param provider: ? Optional instance of the provider where the OdbNetwork to import is found.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc3a505076dbc1b5097bafec69c8421f5bba3990c389ea599ed88dc2bcb7758b)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
        return typing.cast("_cdktn_78ede62e.ImportableResource", jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#create OdbNetwork#create}
        :param delete: A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Setting a timeout for a Delete operation is only applicable if changes are saved into state before the destroy operation occurs. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#delete OdbNetwork#delete}
        :param update: A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#update OdbNetwork#update}
        '''
        value = OdbNetworkTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAvailabilityZone")
    def reset_availability_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAvailabilityZone", []))

    @jsii.member(jsii_name="resetCustomDomainName")
    def reset_custom_domain_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomDomainName", []))

    @jsii.member(jsii_name="resetDefaultDnsPrefix")
    def reset_default_dns_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefaultDnsPrefix", []))

    @jsii.member(jsii_name="resetDeleteAssociatedResources")
    def reset_delete_associated_resources(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeleteAssociatedResources", []))

    @jsii.member(jsii_name="resetKmsAccess")
    def reset_kms_access(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKmsAccess", []))

    @jsii.member(jsii_name="resetKmsPolicyDocument")
    def reset_kms_policy_document(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKmsPolicyDocument", []))

    @jsii.member(jsii_name="resetRegion")
    def reset_region(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegion", []))

    @jsii.member(jsii_name="resetS3PolicyDocument")
    def reset_s3_policy_document(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetS3PolicyDocument", []))

    @jsii.member(jsii_name="resetStsAccess")
    def reset_sts_access(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStsAccess", []))

    @jsii.member(jsii_name="resetStsPolicyDocument")
    def reset_sts_policy_document(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStsPolicyDocument", []))

    @jsii.member(jsii_name="resetTags")
    def reset_tags(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTags", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.member(jsii_name="synthesizeHclAttributes")
    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))

    @jsii.python.classproperty
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "arn"))

    @builtins.property
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property
    @jsii.member(jsii_name="managedServices")
    def managed_services(self) -> "OdbNetworkManagedServicesList":
        return typing.cast("OdbNetworkManagedServicesList", jsii.get(self, "managedServices"))

    @builtins.property
    @jsii.member(jsii_name="ociDnsForwardingConfigs")
    def oci_dns_forwarding_configs(self) -> "OdbNetworkOciDnsForwardingConfigsList":
        return typing.cast("OdbNetworkOciDnsForwardingConfigsList", jsii.get(self, "ociDnsForwardingConfigs"))

    @builtins.property
    @jsii.member(jsii_name="ociNetworkAnchorId")
    def oci_network_anchor_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ociNetworkAnchorId"))

    @builtins.property
    @jsii.member(jsii_name="ociNetworkAnchorUrl")
    def oci_network_anchor_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ociNetworkAnchorUrl"))

    @builtins.property
    @jsii.member(jsii_name="ociResourceAnchorName")
    def oci_resource_anchor_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ociResourceAnchorName"))

    @builtins.property
    @jsii.member(jsii_name="ociVcnId")
    def oci_vcn_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ociVcnId"))

    @builtins.property
    @jsii.member(jsii_name="ociVcnUrl")
    def oci_vcn_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ociVcnUrl"))

    @builtins.property
    @jsii.member(jsii_name="peeredCidrs")
    def peered_cidrs(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "peeredCidrs"))

    @builtins.property
    @jsii.member(jsii_name="percentProgress")
    def percent_progress(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "percentProgress"))

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property
    @jsii.member(jsii_name="statusReason")
    def status_reason(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusReason"))

    @builtins.property
    @jsii.member(jsii_name="tagsAll")
    def tags_all(self) -> "_cdktn_78ede62e.StringMap":
        return typing.cast("_cdktn_78ede62e.StringMap", jsii.get(self, "tagsAll"))

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "OdbNetworkTimeoutsOutputReference":
        return typing.cast("OdbNetworkTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneIdInput")
    def availability_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "availabilityZoneIdInput"))

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneInput")
    def availability_zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "availabilityZoneInput"))

    @builtins.property
    @jsii.member(jsii_name="backupSubnetCidrInput")
    def backup_subnet_cidr_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backupSubnetCidrInput"))

    @builtins.property
    @jsii.member(jsii_name="clientSubnetCidrInput")
    def client_subnet_cidr_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clientSubnetCidrInput"))

    @builtins.property
    @jsii.member(jsii_name="customDomainNameInput")
    def custom_domain_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customDomainNameInput"))

    @builtins.property
    @jsii.member(jsii_name="defaultDnsPrefixInput")
    def default_dns_prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "defaultDnsPrefixInput"))

    @builtins.property
    @jsii.member(jsii_name="deleteAssociatedResourcesInput")
    def delete_associated_resources_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"]], jsii.get(self, "deleteAssociatedResourcesInput"))

    @builtins.property
    @jsii.member(jsii_name="displayNameInput")
    def display_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "displayNameInput"))

    @builtins.property
    @jsii.member(jsii_name="kmsAccessInput")
    def kms_access_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "kmsAccessInput"))

    @builtins.property
    @jsii.member(jsii_name="kmsPolicyDocumentInput")
    def kms_policy_document_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "kmsPolicyDocumentInput"))

    @builtins.property
    @jsii.member(jsii_name="regionInput")
    def region_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "regionInput"))

    @builtins.property
    @jsii.member(jsii_name="s3AccessInput")
    def s3_access_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "s3AccessInput"))

    @builtins.property
    @jsii.member(jsii_name="s3PolicyDocumentInput")
    def s3_policy_document_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "s3PolicyDocumentInput"))

    @builtins.property
    @jsii.member(jsii_name="stsAccessInput")
    def sts_access_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "stsAccessInput"))

    @builtins.property
    @jsii.member(jsii_name="stsPolicyDocumentInput")
    def sts_policy_document_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "stsPolicyDocumentInput"))

    @builtins.property
    @jsii.member(jsii_name="tagsInput")
    def tags_input(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "tagsInput"))

    @builtins.property
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union["_cdktn_78ede62e.IResolvable", "OdbNetworkTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union["_cdktn_78ede62e.IResolvable", "OdbNetworkTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property
    @jsii.member(jsii_name="zeroEtlAccessInput")
    def zero_etl_access_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zeroEtlAccessInput"))

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "availabilityZone"))

    @availability_zone.setter
    def availability_zone(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d95925620d90b6524197644e406307afbe4050cf8cc0a28ce52fc3f9336ee0db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "availabilityZone", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneId")
    def availability_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "availabilityZoneId"))

    @availability_zone_id.setter
    def availability_zone_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a18301d0667b7684fc4286f5550bf517b66bdfbc714db016c1f7306cb5aedee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "availabilityZoneId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="backupSubnetCidr")
    def backup_subnet_cidr(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backupSubnetCidr"))

    @backup_subnet_cidr.setter
    def backup_subnet_cidr(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fcbe38bba32e34daab3d201abdbfff2da869ca1562a8704e9e640828d42c7f6d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "backupSubnetCidr", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="clientSubnetCidr")
    def client_subnet_cidr(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clientSubnetCidr"))

    @client_subnet_cidr.setter
    def client_subnet_cidr(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9892e306b52cc7730b3e7f2fe28c6aa77f2d9a61f458a337bb6f81688389acc0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "clientSubnetCidr", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="customDomainName")
    def custom_domain_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customDomainName"))

    @custom_domain_name.setter
    def custom_domain_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd44da5bafef55f874e14aa97f49beed7f0b6f2a898393dc32c4ebdac729d068)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "customDomainName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="defaultDnsPrefix")
    def default_dns_prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "defaultDnsPrefix"))

    @default_dns_prefix.setter
    def default_dns_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b880c56d1a6da226c3796bbd4f021c44d3fe3a26bd470d6adacfa6564168ecb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "defaultDnsPrefix", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="deleteAssociatedResources")
    def delete_associated_resources(
        self,
    ) -> typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"]:
        return typing.cast(typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"], jsii.get(self, "deleteAssociatedResources"))

    @delete_associated_resources.setter
    def delete_associated_resources(
        self,
        value: typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00a07f50639b175b15ae604739464071bdd167bec3bcc35f45c08534a8478e10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "deleteAssociatedResources", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "displayName"))

    @display_name.setter
    def display_name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00aa854ceac3bc79e93cb7177cede62259122b094fd53076b24d4b9af8c90b8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "displayName", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="kmsAccess")
    def kms_access(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "kmsAccess"))

    @kms_access.setter
    def kms_access(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4915572b6f73ae4068336d36611f057e3cce92c58e9444c3840f18b3f7a714eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "kmsAccess", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="kmsPolicyDocument")
    def kms_policy_document(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "kmsPolicyDocument"))

    @kms_policy_document.setter
    def kms_policy_document(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a71749b2d786426562eadb7fd97c1c41244d98f65f1ca2ecaf0c99ff13161d55)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "kmsPolicyDocument", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "region"))

    @region.setter
    def region(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba77dd4b0fdd44169021a479cb7f3cf1083dc8932fd9cad50aa50cec52dc8d87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "region", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="s3Access")
    def s3_access(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "s3Access"))

    @s3_access.setter
    def s3_access(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4de1257136976736dd6234efc875ad1d380c03a8d7d415ea39e475724b14cbb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "s3Access", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="s3PolicyDocument")
    def s3_policy_document(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "s3PolicyDocument"))

    @s3_policy_document.setter
    def s3_policy_document(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea8d65344bdd83a8c715dfd50ad3962dfc78627db9669b45b20642a5c95a578c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "s3PolicyDocument", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stsAccess")
    def sts_access(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stsAccess"))

    @sts_access.setter
    def sts_access(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a559472fa6ed2b595e163f91ed9b6ec27f08ef1a51371d883d55257ce7170906)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stsAccess", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="stsPolicyDocument")
    def sts_policy_document(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stsPolicyDocument"))

    @sts_policy_document.setter
    def sts_policy_document(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8038bd9ad36f912a232b74fab5bfdf290fdd03b0641e42d3c212da358944723b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "stsPolicyDocument", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "tags"))

    @tags.setter
    def tags(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24bed4b81cc39fe9e0d9bc6dd7f83445cf74213d82357dae77d76f674626fa48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tags", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="zeroEtlAccess")
    def zero_etl_access(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zeroEtlAccess"))

    @zero_etl_access.setter
    def zero_etl_access(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13bf847abcbb87e7cc99061d3d0824982d0dd5017e2844252bf70cbd25f5f354)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "zeroEtlAccess", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkConfig",
    jsii_struct_bases=[_cdktn_78ede62e.TerraformMetaArguments],
    name_mapping={
        "connection": "connection",
        "count": "count",
        "depends_on": "dependsOn",
        "for_each": "forEach",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "provisioners": "provisioners",
        "availability_zone_id": "availabilityZoneId",
        "backup_subnet_cidr": "backupSubnetCidr",
        "client_subnet_cidr": "clientSubnetCidr",
        "display_name": "displayName",
        "s3_access": "s3Access",
        "zero_etl_access": "zeroEtlAccess",
        "availability_zone": "availabilityZone",
        "custom_domain_name": "customDomainName",
        "default_dns_prefix": "defaultDnsPrefix",
        "delete_associated_resources": "deleteAssociatedResources",
        "kms_access": "kmsAccess",
        "kms_policy_document": "kmsPolicyDocument",
        "region": "region",
        "s3_policy_document": "s3PolicyDocument",
        "sts_access": "stsAccess",
        "sts_policy_document": "stsPolicyDocument",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class OdbNetworkConfig(_cdktn_78ede62e.TerraformMetaArguments):
    def __init__(
        self,
        *,
        connection: typing.Optional[typing.Union[typing.Union["_cdktn_78ede62e.SSHProvisionerConnection", typing.Dict[builtins.str, typing.Any]], typing.Union["_cdktn_78ede62e.WinrmProvisionerConnection", typing.Dict[builtins.str, typing.Any]]]] = None,
        count: typing.Optional[typing.Union[jsii.Number, "_cdktn_78ede62e.TerraformCount"]] = None,
        depends_on: typing.Optional[typing.Sequence["_cdktn_78ede62e.ITerraformDependable"]] = None,
        for_each: typing.Optional["_cdktn_78ede62e.ITerraformIterator"] = None,
        lifecycle: typing.Optional[typing.Union["_cdktn_78ede62e.TerraformResourceLifecycle", typing.Dict[builtins.str, typing.Any]]] = None,
        provider: typing.Optional["_cdktn_78ede62e.TerraformProvider"] = None,
        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union["_cdktn_78ede62e.FileProvisioner", typing.Dict[builtins.str, typing.Any]], typing.Union["_cdktn_78ede62e.LocalExecProvisioner", typing.Dict[builtins.str, typing.Any]], typing.Union["_cdktn_78ede62e.RemoteExecProvisioner", typing.Dict[builtins.str, typing.Any]]]]] = None,
        availability_zone_id: builtins.str,
        backup_subnet_cidr: builtins.str,
        client_subnet_cidr: builtins.str,
        display_name: builtins.str,
        s3_access: builtins.str,
        zero_etl_access: builtins.str,
        availability_zone: typing.Optional[builtins.str] = None,
        custom_domain_name: typing.Optional[builtins.str] = None,
        default_dns_prefix: typing.Optional[builtins.str] = None,
        delete_associated_resources: typing.Optional[typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"]] = None,
        kms_access: typing.Optional[builtins.str] = None,
        kms_policy_document: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        s3_policy_document: typing.Optional[builtins.str] = None,
        sts_access: typing.Optional[builtins.str] = None,
        sts_policy_document: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional[typing.Union["OdbNetworkTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param connection: 
        :param count: 
        :param depends_on: 
        :param for_each: 
        :param lifecycle: 
        :param provider: 
        :param provisioners: 
        :param availability_zone_id: The AZ ID of the AZ where the ODB network is located. Changing this will force terraform to create new resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#availability_zone_id OdbNetwork#availability_zone_id}
        :param backup_subnet_cidr: The CIDR range of the backup subnet for the ODB network. Changing this will force terraform to create new resource. Constraints: - Must not overlap with the CIDR range of the client subnet. - Must not overlap with the CIDR ranges of the VPCs that are connected to the ODB network. - Must not use the following CIDR ranges that are reserved by OCI: - 100.106.0.0/16 and 100.107.0.0/16 - 169.254.0.0/16 - 224.0.0.0 - 239.255.255.255 - 240.0.0.0 - 255.255.255.255 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#backup_subnet_cidr OdbNetwork#backup_subnet_cidr}
        :param client_subnet_cidr: The CIDR notation for the network resource. Changing this will force terraform to create new resource. Constraints: - Must not overlap with the CIDR range of the backup subnet. - Must not overlap with the CIDR ranges of the VPCs that are connected to the ODB network. - Must not use the following CIDR ranges that are reserved by OCI: - 100.106.0.0/16 and 100.107.0.0/16 - 169.254.0.0/16 - 224.0.0.0 - 239.255.255.255 - 240.0.0.0 - 255.255.255.255 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#client_subnet_cidr OdbNetwork#client_subnet_cidr}
        :param display_name: The user-friendly name for the odb network. Changing this will force terraform to create a new resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#display_name OdbNetwork#display_name}
        :param s3_access: Specifies the configuration for Amazon S3 access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#s3_access OdbNetwork#s3_access}
        :param zero_etl_access: Specifies the configuration for Zero-ETL access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#zero_etl_access OdbNetwork#zero_etl_access}
        :param availability_zone: The name of the Availability Zone (AZ) where the odb network is located. Changing this will force terraform to create new resource Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#availability_zone OdbNetwork#availability_zone}
        :param custom_domain_name: The name of the custom domain that the network is located. custom_domain_name and default_dns_prefix both can't be given. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#custom_domain_name OdbNetwork#custom_domain_name}
        :param default_dns_prefix: The default DNS prefix for the network resource. Changing this will force terraform to create new resource. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#default_dns_prefix OdbNetwork#default_dns_prefix}
        :param delete_associated_resources: If set to true deletes associated OCI resources. Default false. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#delete_associated_resources OdbNetwork#delete_associated_resources}
        :param kms_access: Specifies the configuration for Amazon KMS access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#kms_access OdbNetwork#kms_access}
        :param kms_policy_document: Specifies the endpoint policy for Amazon KMS access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#kms_policy_document OdbNetwork#kms_policy_document}
        :param region: Region where this resource will be `managed <https://docs.aws.amazon.com/general/latest/gr/rande.html#regional-endpoints>`_. Defaults to the Region set in the `provider configuration <https://registry.terraform.io/providers/hashicorp/aws/latest/docs#aws-configuration-reference>`_. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#region OdbNetwork#region}
        :param s3_policy_document: Specifies the endpoint policy for Amazon S3 access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#s3_policy_document OdbNetwork#s3_policy_document}
        :param sts_access: Specifies the configuration for Amazon STS access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#sts_access OdbNetwork#sts_access}
        :param sts_policy_document: Specifies the endpoint policy for Amazon STS access from the ODB network. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#sts_policy_document OdbNetwork#sts_policy_document}
        :param tags: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#tags OdbNetwork#tags}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#timeouts OdbNetwork#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = _cdktn_78ede62e.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = OdbNetworkTimeouts(**timeouts)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09e4804f09c71cab733d18188a809dd232c9f16265f9abe836e3ce9721d31c0f)
            check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
            check_type(argname="argument for_each", value=for_each, expected_type=type_hints["for_each"])
            check_type(argname="argument lifecycle", value=lifecycle, expected_type=type_hints["lifecycle"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
            check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
            check_type(argname="argument availability_zone_id", value=availability_zone_id, expected_type=type_hints["availability_zone_id"])
            check_type(argname="argument backup_subnet_cidr", value=backup_subnet_cidr, expected_type=type_hints["backup_subnet_cidr"])
            check_type(argname="argument client_subnet_cidr", value=client_subnet_cidr, expected_type=type_hints["client_subnet_cidr"])
            check_type(argname="argument display_name", value=display_name, expected_type=type_hints["display_name"])
            check_type(argname="argument s3_access", value=s3_access, expected_type=type_hints["s3_access"])
            check_type(argname="argument zero_etl_access", value=zero_etl_access, expected_type=type_hints["zero_etl_access"])
            check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
            check_type(argname="argument custom_domain_name", value=custom_domain_name, expected_type=type_hints["custom_domain_name"])
            check_type(argname="argument default_dns_prefix", value=default_dns_prefix, expected_type=type_hints["default_dns_prefix"])
            check_type(argname="argument delete_associated_resources", value=delete_associated_resources, expected_type=type_hints["delete_associated_resources"])
            check_type(argname="argument kms_access", value=kms_access, expected_type=type_hints["kms_access"])
            check_type(argname="argument kms_policy_document", value=kms_policy_document, expected_type=type_hints["kms_policy_document"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument s3_policy_document", value=s3_policy_document, expected_type=type_hints["s3_policy_document"])
            check_type(argname="argument sts_access", value=sts_access, expected_type=type_hints["sts_access"])
            check_type(argname="argument sts_policy_document", value=sts_policy_document, expected_type=type_hints["sts_policy_document"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "availability_zone_id": availability_zone_id,
            "backup_subnet_cidr": backup_subnet_cidr,
            "client_subnet_cidr": client_subnet_cidr,
            "display_name": display_name,
            "s3_access": s3_access,
            "zero_etl_access": zero_etl_access,
        }
        if connection is not None:
            self._values["connection"] = connection
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if for_each is not None:
            self._values["for_each"] = for_each
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if provisioners is not None:
            self._values["provisioners"] = provisioners
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if custom_domain_name is not None:
            self._values["custom_domain_name"] = custom_domain_name
        if default_dns_prefix is not None:
            self._values["default_dns_prefix"] = default_dns_prefix
        if delete_associated_resources is not None:
            self._values["delete_associated_resources"] = delete_associated_resources
        if kms_access is not None:
            self._values["kms_access"] = kms_access
        if kms_policy_document is not None:
            self._values["kms_policy_document"] = kms_policy_document
        if region is not None:
            self._values["region"] = region
        if s3_policy_document is not None:
            self._values["s3_policy_document"] = s3_policy_document
        if sts_access is not None:
            self._values["sts_access"] = sts_access
        if sts_policy_document is not None:
            self._values["sts_policy_document"] = sts_policy_document
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def connection(
        self,
    ) -> typing.Optional[typing.Union["_cdktn_78ede62e.SSHProvisionerConnection", "_cdktn_78ede62e.WinrmProvisionerConnection"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("connection")
        return typing.cast(typing.Optional[typing.Union["_cdktn_78ede62e.SSHProvisionerConnection", "_cdktn_78ede62e.WinrmProvisionerConnection"]], result)

    @builtins.property
    def count(
        self,
    ) -> typing.Optional[typing.Union[jsii.Number, "_cdktn_78ede62e.TerraformCount"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[typing.Union[jsii.Number, "_cdktn_78ede62e.TerraformCount"]], result)

    @builtins.property
    def depends_on(
        self,
    ) -> typing.Optional[typing.List["_cdktn_78ede62e.ITerraformDependable"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List["_cdktn_78ede62e.ITerraformDependable"]], result)

    @builtins.property
    def for_each(self) -> typing.Optional["_cdktn_78ede62e.ITerraformIterator"]:
        '''
        :stability: experimental
        '''
        result = self._values.get("for_each")
        return typing.cast(typing.Optional["_cdktn_78ede62e.ITerraformIterator"], result)

    @builtins.property
    def lifecycle(
        self,
    ) -> typing.Optional["_cdktn_78ede62e.TerraformResourceLifecycle"]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional["_cdktn_78ede62e.TerraformResourceLifecycle"], result)

    @builtins.property
    def provider(self) -> typing.Optional["_cdktn_78ede62e.TerraformProvider"]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional["_cdktn_78ede62e.TerraformProvider"], result)

    @builtins.property
    def provisioners(
        self,
    ) -> typing.Optional[typing.List[typing.Union["_cdktn_78ede62e.FileProvisioner", "_cdktn_78ede62e.LocalExecProvisioner", "_cdktn_78ede62e.RemoteExecProvisioner"]]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provisioners")
        return typing.cast(typing.Optional[typing.List[typing.Union["_cdktn_78ede62e.FileProvisioner", "_cdktn_78ede62e.LocalExecProvisioner", "_cdktn_78ede62e.RemoteExecProvisioner"]]], result)

    @builtins.property
    def availability_zone_id(self) -> builtins.str:
        '''The AZ ID of the AZ where the ODB network is located.

        Changing this will force terraform to create new resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#availability_zone_id OdbNetwork#availability_zone_id}
        '''
        result = self._values.get("availability_zone_id")
        assert result is not None, "Required property 'availability_zone_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def backup_subnet_cidr(self) -> builtins.str:
        '''The CIDR range of the backup subnet for the ODB network.

        Changing this will force terraform to create new resource.
        Constraints:

        - Must not overlap with the CIDR range of the client subnet.
        - Must not overlap with the CIDR ranges of the VPCs that are connected to the
          ODB network.
        - Must not use the following CIDR ranges that are reserved by OCI:
        - 100.106.0.0/16 and 100.107.0.0/16
        - 169.254.0.0/16
        - 224.0.0.0 - 239.255.255.255
        - 240.0.0.0 - 255.255.255.255

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#backup_subnet_cidr OdbNetwork#backup_subnet_cidr}
        '''
        result = self._values.get("backup_subnet_cidr")
        assert result is not None, "Required property 'backup_subnet_cidr' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def client_subnet_cidr(self) -> builtins.str:
        '''The CIDR notation for the network resource.

        Changing this will force terraform to create new resource.
        Constraints:

        - Must not overlap with the CIDR range of the backup subnet.
        - Must not overlap with the CIDR ranges of the VPCs that are connected to the
          ODB network.
        - Must not use the following CIDR ranges that are reserved by OCI:
        - 100.106.0.0/16 and 100.107.0.0/16
        - 169.254.0.0/16
        - 224.0.0.0 - 239.255.255.255
        - 240.0.0.0 - 255.255.255.255

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#client_subnet_cidr OdbNetwork#client_subnet_cidr}
        '''
        result = self._values.get("client_subnet_cidr")
        assert result is not None, "Required property 'client_subnet_cidr' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def display_name(self) -> builtins.str:
        '''The user-friendly name for the odb network. Changing this will force terraform to create a new resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#display_name OdbNetwork#display_name}
        '''
        result = self._values.get("display_name")
        assert result is not None, "Required property 'display_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def s3_access(self) -> builtins.str:
        '''Specifies the configuration for Amazon S3 access from the ODB network.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#s3_access OdbNetwork#s3_access}
        '''
        result = self._values.get("s3_access")
        assert result is not None, "Required property 's3_access' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zero_etl_access(self) -> builtins.str:
        '''Specifies the configuration for Zero-ETL access from the ODB network.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#zero_etl_access OdbNetwork#zero_etl_access}
        '''
        result = self._values.get("zero_etl_access")
        assert result is not None, "Required property 'zero_etl_access' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def availability_zone(self) -> typing.Optional[builtins.str]:
        '''The name of the Availability Zone (AZ) where the odb network is located.

        Changing this will force terraform to create new resource

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#availability_zone OdbNetwork#availability_zone}
        '''
        result = self._values.get("availability_zone")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_domain_name(self) -> typing.Optional[builtins.str]:
        '''The name of the custom domain that the network is located. custom_domain_name and default_dns_prefix both can't be given.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#custom_domain_name OdbNetwork#custom_domain_name}
        '''
        result = self._values.get("custom_domain_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def default_dns_prefix(self) -> typing.Optional[builtins.str]:
        '''The default DNS prefix for the network resource. Changing this will force terraform to create new resource.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#default_dns_prefix OdbNetwork#default_dns_prefix}
        '''
        result = self._values.get("default_dns_prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete_associated_resources(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"]]:
        '''If set to true deletes associated OCI resources. Default false.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#delete_associated_resources OdbNetwork#delete_associated_resources}
        '''
        result = self._values.get("delete_associated_resources")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, "_cdktn_78ede62e.IResolvable"]], result)

    @builtins.property
    def kms_access(self) -> typing.Optional[builtins.str]:
        '''Specifies the configuration for Amazon KMS access from the ODB network.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#kms_access OdbNetwork#kms_access}
        '''
        result = self._values.get("kms_access")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def kms_policy_document(self) -> typing.Optional[builtins.str]:
        '''Specifies the endpoint policy for Amazon KMS access from the ODB network.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#kms_policy_document OdbNetwork#kms_policy_document}
        '''
        result = self._values.get("kms_policy_document")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def region(self) -> typing.Optional[builtins.str]:
        '''Region where this resource will be `managed <https://docs.aws.amazon.com/general/latest/gr/rande.html#regional-endpoints>`_. Defaults to the Region set in the `provider configuration <https://registry.terraform.io/providers/hashicorp/aws/latest/docs#aws-configuration-reference>`_.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#region OdbNetwork#region}
        '''
        result = self._values.get("region")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def s3_policy_document(self) -> typing.Optional[builtins.str]:
        '''Specifies the endpoint policy for Amazon S3 access from the ODB network.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#s3_policy_document OdbNetwork#s3_policy_document}
        '''
        result = self._values.get("s3_policy_document")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sts_access(self) -> typing.Optional[builtins.str]:
        '''Specifies the configuration for Amazon STS access from the ODB network.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#sts_access OdbNetwork#sts_access}
        '''
        result = self._values.get("sts_access")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sts_policy_document(self) -> typing.Optional[builtins.str]:
        '''Specifies the endpoint policy for Amazon STS access from the ODB network.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#sts_policy_document OdbNetwork#sts_policy_document}
        '''
        result = self._values.get("sts_policy_document")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#tags OdbNetwork#tags}.'''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["OdbNetworkTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#timeouts OdbNetwork#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["OdbNetworkTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServices",
    jsii_struct_bases=[],
    name_mapping={},
)
class OdbNetworkManagedServices:
    def __init__(self) -> None:
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkManagedServices(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesKmsAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class OdbNetworkManagedServicesKmsAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkManagedServicesKmsAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OdbNetworkManagedServicesKmsAccessList(
    _cdktn_78ede62e.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesKmsAccessList",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a0f8fe844b9d426d6706b7603202f9cd0a1aeb06aa46d4fb9aec355b882ee9b0)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "OdbNetworkManagedServicesKmsAccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bb63034bc4ec4c6f606b976205bce1f534cf8e7525eb7efbd1e1e39f4f21c23)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("OdbNetworkManagedServicesKmsAccessOutputReference", jsii.invoke(self, "get", [index]))


class OdbNetworkManagedServicesKmsAccessOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesKmsAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe6e8512faec34472dae1f2eec250936f00e9c85fe841c9c9c4c4b58253d5d74)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "domainName"))

    @builtins.property
    @jsii.member(jsii_name="ipv4Addresses")
    def ipv4_addresses(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "ipv4Addresses"))

    @builtins.property
    @jsii.member(jsii_name="kmsPolicyDocument")
    def kms_policy_document(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "kmsPolicyDocument"))

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional["OdbNetworkManagedServicesKmsAccess"]:
        return typing.cast(typing.Optional["OdbNetworkManagedServicesKmsAccess"], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional["OdbNetworkManagedServicesKmsAccess"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6036771eb0f1c258f39666cf937f96291264580b4ee1f9c86873bdbc3c9ca127)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class OdbNetworkManagedServicesList(
    _cdktn_78ede62e.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesList",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5706e05666772b09e5f6da86b26b1d3656ffc00559cd37da9e21290f98b8842c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "OdbNetworkManagedServicesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e2718494be95a06fc1239c348f55d3ae9f0bbbdf8f9f5424f9e87ad47b48465)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("OdbNetworkManagedServicesOutputReference", jsii.invoke(self, "get", [index]))


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesManagedS3BackupAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class OdbNetworkManagedServicesManagedS3BackupAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkManagedServicesManagedS3BackupAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OdbNetworkManagedServicesManagedS3BackupAccessList(
    _cdktn_78ede62e.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesManagedS3BackupAccessList",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5812ba9bc673f27ab122b4a2681e01642952bd3ea097efe199eb974042134a0d)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "OdbNetworkManagedServicesManagedS3BackupAccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2673d04c4966ce3366a3b9eba426a946c7c76382e7ae15251289a624de0e352)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("OdbNetworkManagedServicesManagedS3BackupAccessOutputReference", jsii.invoke(self, "get", [index]))


class OdbNetworkManagedServicesManagedS3BackupAccessOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesManagedS3BackupAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0645d122aaa83139ef72772e01f1669021251b8088da2a2b0bcaad80ac4e3455)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="ipv4Addresses")
    def ipv4_addresses(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "ipv4Addresses"))

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional["OdbNetworkManagedServicesManagedS3BackupAccess"]:
        return typing.cast(typing.Optional["OdbNetworkManagedServicesManagedS3BackupAccess"], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional["OdbNetworkManagedServicesManagedS3BackupAccess"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc4c52c3dfe274548600a49873ca322adf03cb404d1fd0353f548e614f46810f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class OdbNetworkManagedServicesOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0438c9e9ce7e30640609c34521c15a81a08d095514121ce321867b7b8e914a9f)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="kmsAccess")
    def kms_access(self) -> "OdbNetworkManagedServicesKmsAccessList":
        return typing.cast("OdbNetworkManagedServicesKmsAccessList", jsii.get(self, "kmsAccess"))

    @builtins.property
    @jsii.member(jsii_name="managedS3BackupAccess")
    def managed_s3_backup_access(
        self,
    ) -> "OdbNetworkManagedServicesManagedS3BackupAccessList":
        return typing.cast("OdbNetworkManagedServicesManagedS3BackupAccessList", jsii.get(self, "managedS3BackupAccess"))

    @builtins.property
    @jsii.member(jsii_name="managedServiceIpv4Cidrs")
    def managed_service_ipv4_cidrs(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "managedServiceIpv4Cidrs"))

    @builtins.property
    @jsii.member(jsii_name="resourceGatewayArn")
    def resource_gateway_arn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceGatewayArn"))

    @builtins.property
    @jsii.member(jsii_name="s3Access")
    def s3_access(self) -> "OdbNetworkManagedServicesS3AccessList":
        return typing.cast("OdbNetworkManagedServicesS3AccessList", jsii.get(self, "s3Access"))

    @builtins.property
    @jsii.member(jsii_name="serviceNetworkArn")
    def service_network_arn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceNetworkArn"))

    @builtins.property
    @jsii.member(jsii_name="serviceNetworkEndpoint")
    def service_network_endpoint(
        self,
    ) -> "OdbNetworkManagedServicesServiceNetworkEndpointList":
        return typing.cast("OdbNetworkManagedServicesServiceNetworkEndpointList", jsii.get(self, "serviceNetworkEndpoint"))

    @builtins.property
    @jsii.member(jsii_name="stsAccess")
    def sts_access(self) -> "OdbNetworkManagedServicesStsAccessList":
        return typing.cast("OdbNetworkManagedServicesStsAccessList", jsii.get(self, "stsAccess"))

    @builtins.property
    @jsii.member(jsii_name="zeroEtlAccess")
    def zero_etl_access(self) -> "OdbNetworkManagedServicesZeroEtlAccessList":
        return typing.cast("OdbNetworkManagedServicesZeroEtlAccessList", jsii.get(self, "zeroEtlAccess"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional["OdbNetworkManagedServices"]:
        return typing.cast(typing.Optional["OdbNetworkManagedServices"], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional["OdbNetworkManagedServices"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86f57cb1b9d0daefc51304897af84c972c89fa613fa7e9db43586546608af382)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesS3Access",
    jsii_struct_bases=[],
    name_mapping={},
)
class OdbNetworkManagedServicesS3Access:
    def __init__(self) -> None:
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkManagedServicesS3Access(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OdbNetworkManagedServicesS3AccessList(
    _cdktn_78ede62e.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesS3AccessList",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44ae9530957cd38c5aad3696345e2237bffae5c09a4a3db2fa8167027cd05752)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "OdbNetworkManagedServicesS3AccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a32a5497c528dc41f641d137e782452e5d7f107cda86c21563b9064d21f965e3)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("OdbNetworkManagedServicesS3AccessOutputReference", jsii.invoke(self, "get", [index]))


class OdbNetworkManagedServicesS3AccessOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesS3AccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8a7254f635a1a36f2e2b0cff7d88e8e0aa6279ec2d0c113deee930c15c226ff)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "domainName"))

    @builtins.property
    @jsii.member(jsii_name="ipv4Addresses")
    def ipv4_addresses(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "ipv4Addresses"))

    @builtins.property
    @jsii.member(jsii_name="s3PolicyDocument")
    def s3_policy_document(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "s3PolicyDocument"))

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional["OdbNetworkManagedServicesS3Access"]:
        return typing.cast(typing.Optional["OdbNetworkManagedServicesS3Access"], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional["OdbNetworkManagedServicesS3Access"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5153acbaf3f1a56b7ec27d0e16fb96380cfc76e4f807a40f1f94750c59b6bce1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesServiceNetworkEndpoint",
    jsii_struct_bases=[],
    name_mapping={},
)
class OdbNetworkManagedServicesServiceNetworkEndpoint:
    def __init__(self) -> None:
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkManagedServicesServiceNetworkEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OdbNetworkManagedServicesServiceNetworkEndpointList(
    _cdktn_78ede62e.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesServiceNetworkEndpointList",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cdc08449d2e443bf17cf75eafb87b49006d202b4525736317cf6defcf55bf9e8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "OdbNetworkManagedServicesServiceNetworkEndpointOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51e0a683e39c640a670a66b8bfd106e12cbea61942f46da3576543dc27696a93)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("OdbNetworkManagedServicesServiceNetworkEndpointOutputReference", jsii.invoke(self, "get", [index]))


class OdbNetworkManagedServicesServiceNetworkEndpointOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesServiceNetworkEndpointOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c86bce760aa612c659fb42ab825fd75d5fe54799e8fa542f4b8c1cb530353a9c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointId")
    def vpc_endpoint_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "vpcEndpointId"))

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointType")
    def vpc_endpoint_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "vpcEndpointType"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional["OdbNetworkManagedServicesServiceNetworkEndpoint"]:
        return typing.cast(typing.Optional["OdbNetworkManagedServicesServiceNetworkEndpoint"], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional["OdbNetworkManagedServicesServiceNetworkEndpoint"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a084ca11b5b9c54f8cfa247d49d8d2e187899530ab85bd0bab6e4d680fc2b7f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesStsAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class OdbNetworkManagedServicesStsAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkManagedServicesStsAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OdbNetworkManagedServicesStsAccessList(
    _cdktn_78ede62e.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesStsAccessList",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__218ce58ce6a0ba9ebe9a7656092ae7dcc852d081e5e31d8f47d700babe08e5d8)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "OdbNetworkManagedServicesStsAccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c07e793d8b9e3908dc0b82f6ed60ca255f78d31dd757d68f5bbc8df9a4266e37)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("OdbNetworkManagedServicesStsAccessOutputReference", jsii.invoke(self, "get", [index]))


class OdbNetworkManagedServicesStsAccessOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesStsAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d4bb4296f6e6b8d335bf5002d84e29b8769ef555ebd43aa94bda371e1030296)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "domainName"))

    @builtins.property
    @jsii.member(jsii_name="ipv4Addresses")
    def ipv4_addresses(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "ipv4Addresses"))

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property
    @jsii.member(jsii_name="stsPolicyDocument")
    def sts_policy_document(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "stsPolicyDocument"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional["OdbNetworkManagedServicesStsAccess"]:
        return typing.cast(typing.Optional["OdbNetworkManagedServicesStsAccess"], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional["OdbNetworkManagedServicesStsAccess"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__587c12f5d6d843ab1e38a37ba4c922f1aaeaefac6e3d2334f78f59da24e8d879)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesZeroEtlAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class OdbNetworkManagedServicesZeroEtlAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkManagedServicesZeroEtlAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OdbNetworkManagedServicesZeroEtlAccessList(
    _cdktn_78ede62e.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesZeroEtlAccessList",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a309c2e06280afee8635be58da30f280c7d8c168ab655e00f2889eb3835b95c)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "OdbNetworkManagedServicesZeroEtlAccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2788ae580603a61faf0c4b3db940b8f692aa8263ebe06b1cc795406813a24e6a)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("OdbNetworkManagedServicesZeroEtlAccessOutputReference", jsii.invoke(self, "get", [index]))


class OdbNetworkManagedServicesZeroEtlAccessOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkManagedServicesZeroEtlAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9796c044c5e03ff5f541f181bb35cba5f382660d5c6ff1a230fbcc600e2d859e)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="cidr")
    def cidr(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cidr"))

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional["OdbNetworkManagedServicesZeroEtlAccess"]:
        return typing.cast(typing.Optional["OdbNetworkManagedServicesZeroEtlAccess"], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional["OdbNetworkManagedServicesZeroEtlAccess"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71b3b323baf83c47836ac4782c15381cd7d90bd5b1d92007f9e33179eff4728b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkOciDnsForwardingConfigs",
    jsii_struct_bases=[],
    name_mapping={},
)
class OdbNetworkOciDnsForwardingConfigs:
    def __init__(self) -> None:
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkOciDnsForwardingConfigs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OdbNetworkOciDnsForwardingConfigsList(
    _cdktn_78ede62e.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkOciDnsForwardingConfigsList",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3626099940a40141b5d9b6b1b6c457b5497ca66458294152ef918d6020c4e059)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "OdbNetworkOciDnsForwardingConfigsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fdd187780058177e6b99a64a557026a0c1279819bc2078dc968f100647023d97)
            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
        return typing.cast("OdbNetworkOciDnsForwardingConfigsOutputReference", jsii.invoke(self, "get", [index]))


class OdbNetworkOciDnsForwardingConfigsOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkOciDnsForwardingConfigsOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1d86cfee017b00d127461f9a37056b609bba04374ced72169a9c680ba3eb6c2)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "domainName"))

    @builtins.property
    @jsii.member(jsii_name="ociDnsListenerIp")
    def oci_dns_listener_ip(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ociDnsListenerIp"))

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional["OdbNetworkOciDnsForwardingConfigs"]:
        return typing.cast(typing.Optional["OdbNetworkOciDnsForwardingConfigs"], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional["OdbNetworkOciDnsForwardingConfigs"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6a6f4b55b79df4a3ab6840238444f8550cf2aaadef1172087b98794bfa2dfd7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class OdbNetworkTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#create OdbNetwork#create}
        :param delete: A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Setting a timeout for a Delete operation is only applicable if changes are saved into state before the destroy operation occurs. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#delete OdbNetwork#delete}
        :param update: A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#update OdbNetwork#update}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b560d33753cd3a01741250cfb15b84ffd6dfa3bdacaf9207d98bb2084367bcd)
            check_type(argname="argument create", value=create, expected_type=type_hints["create"])
            check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
            check_type(argname="argument update", value=update, expected_type=type_hints["update"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#create OdbNetwork#create}
        '''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Setting a timeout for a Delete operation is only applicable if changes are saved into state before the destroy operation occurs.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#delete OdbNetwork#delete}
        '''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''A string that can be `parsed as a duration <https://pkg.go.dev/time#ParseDuration>`_ consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours).

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.40.0/docs/resources/odb_network#update OdbNetwork#update}
        '''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OdbNetworkTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OdbNetworkTimeoutsOutputReference(
    _cdktn_78ede62e.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktn/provider-aws.odbNetwork.OdbNetworkTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: "_cdktn_78ede62e.IInterpolatingParent",
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1da836746b31ff100061e40d2edc7109d70ad4efef9586fd8d7dfa6dc265eaa3)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff9376bbe9afa03ce5e66e57d64875fde0a0923ed43471d9a2153b8614c73857)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "create", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a6a5abab89926e77d3a3508315e0289f7f098fd490cd94af16f56751954023d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "delete", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__568b314af7d6583608ab871f1619555703a59a115b508a60d819ac7768889f96)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "update", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union["_cdktn_78ede62e.IResolvable", "OdbNetworkTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union["_cdktn_78ede62e.IResolvable", "OdbNetworkTimeouts"]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union["_cdktn_78ede62e.IResolvable", "OdbNetworkTimeouts"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f7cd09015a39394a2ca3506e0307ddbc82e963dfa4c38a337033a8cdc122460)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


__all__ = [
    "OdbNetwork",
    "OdbNetworkConfig",
    "OdbNetworkManagedServices",
    "OdbNetworkManagedServicesKmsAccess",
    "OdbNetworkManagedServicesKmsAccessList",
    "OdbNetworkManagedServicesKmsAccessOutputReference",
    "OdbNetworkManagedServicesList",
    "OdbNetworkManagedServicesManagedS3BackupAccess",
    "OdbNetworkManagedServicesManagedS3BackupAccessList",
    "OdbNetworkManagedServicesManagedS3BackupAccessOutputReference",
    "OdbNetworkManagedServicesOutputReference",
    "OdbNetworkManagedServicesS3Access",
    "OdbNetworkManagedServicesS3AccessList",
    "OdbNetworkManagedServicesS3AccessOutputReference",
    "OdbNetworkManagedServicesServiceNetworkEndpoint",
    "OdbNetworkManagedServicesServiceNetworkEndpointList",
    "OdbNetworkManagedServicesServiceNetworkEndpointOutputReference",
    "OdbNetworkManagedServicesStsAccess",
    "OdbNetworkManagedServicesStsAccessList",
    "OdbNetworkManagedServicesStsAccessOutputReference",
    "OdbNetworkManagedServicesZeroEtlAccess",
    "OdbNetworkManagedServicesZeroEtlAccessList",
    "OdbNetworkManagedServicesZeroEtlAccessOutputReference",
    "OdbNetworkOciDnsForwardingConfigs",
    "OdbNetworkOciDnsForwardingConfigsList",
    "OdbNetworkOciDnsForwardingConfigsOutputReference",
    "OdbNetworkTimeouts",
    "OdbNetworkTimeoutsOutputReference",
]

publication.publish()

def _typecheckingstub__e41518babc6df2c1e4d7b0891415cabda8373c6f45f37933db537b1212cb9db6(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    availability_zone_id: builtins.str,
    backup_subnet_cidr: builtins.str,
    client_subnet_cidr: builtins.str,
    display_name: builtins.str,
    s3_access: builtins.str,
    zero_etl_access: builtins.str,
    availability_zone: typing.Optional[builtins.str] = None,
    custom_domain_name: typing.Optional[builtins.str] = None,
    default_dns_prefix: typing.Optional[builtins.str] = None,
    delete_associated_resources: typing.Optional[typing.Union[builtins.bool, _cdktn_78ede62e.IResolvable]] = None,
    kms_access: typing.Optional[builtins.str] = None,
    kms_policy_document: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    s3_policy_document: typing.Optional[builtins.str] = None,
    sts_access: typing.Optional[builtins.str] = None,
    sts_policy_document: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    timeouts: typing.Optional[typing.Union[OdbNetworkTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
    connection: typing.Optional[typing.Union[typing.Union[_cdktn_78ede62e.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktn_78ede62e.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
    count: typing.Optional[typing.Union[jsii.Number, _cdktn_78ede62e.TerraformCount]] = None,
    depends_on: typing.Optional[typing.Sequence[_cdktn_78ede62e.ITerraformDependable]] = None,
    for_each: typing.Optional[_cdktn_78ede62e.ITerraformIterator] = None,
    lifecycle: typing.Optional[typing.Union[_cdktn_78ede62e.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
    provider: typing.Optional[_cdktn_78ede62e.TerraformProvider] = None,
    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktn_78ede62e.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktn_78ede62e.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktn_78ede62e.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc3a505076dbc1b5097bafec69c8421f5bba3990c389ea599ed88dc2bcb7758b(
    scope: _constructs_77d1e7e8.Construct,
    import_to_id: builtins.str,
    import_from_id: builtins.str,
    provider: typing.Optional[_cdktn_78ede62e.TerraformProvider] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d95925620d90b6524197644e406307afbe4050cf8cc0a28ce52fc3f9336ee0db(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a18301d0667b7684fc4286f5550bf517b66bdfbc714db016c1f7306cb5aedee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcbe38bba32e34daab3d201abdbfff2da869ca1562a8704e9e640828d42c7f6d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9892e306b52cc7730b3e7f2fe28c6aa77f2d9a61f458a337bb6f81688389acc0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd44da5bafef55f874e14aa97f49beed7f0b6f2a898393dc32c4ebdac729d068(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b880c56d1a6da226c3796bbd4f021c44d3fe3a26bd470d6adacfa6564168ecb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00a07f50639b175b15ae604739464071bdd167bec3bcc35f45c08534a8478e10(
    value: typing.Union[builtins.bool, _cdktn_78ede62e.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00aa854ceac3bc79e93cb7177cede62259122b094fd53076b24d4b9af8c90b8f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4915572b6f73ae4068336d36611f057e3cce92c58e9444c3840f18b3f7a714eb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a71749b2d786426562eadb7fd97c1c41244d98f65f1ca2ecaf0c99ff13161d55(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba77dd4b0fdd44169021a479cb7f3cf1083dc8932fd9cad50aa50cec52dc8d87(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4de1257136976736dd6234efc875ad1d380c03a8d7d415ea39e475724b14cbb9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea8d65344bdd83a8c715dfd50ad3962dfc78627db9669b45b20642a5c95a578c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a559472fa6ed2b595e163f91ed9b6ec27f08ef1a51371d883d55257ce7170906(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8038bd9ad36f912a232b74fab5bfdf290fdd03b0641e42d3c212da358944723b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24bed4b81cc39fe9e0d9bc6dd7f83445cf74213d82357dae77d76f674626fa48(
    value: typing.Mapping[builtins.str, builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13bf847abcbb87e7cc99061d3d0824982d0dd5017e2844252bf70cbd25f5f354(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09e4804f09c71cab733d18188a809dd232c9f16265f9abe836e3ce9721d31c0f(
    *,
    connection: typing.Optional[typing.Union[typing.Union[_cdktn_78ede62e.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktn_78ede62e.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
    count: typing.Optional[typing.Union[jsii.Number, _cdktn_78ede62e.TerraformCount]] = None,
    depends_on: typing.Optional[typing.Sequence[_cdktn_78ede62e.ITerraformDependable]] = None,
    for_each: typing.Optional[_cdktn_78ede62e.ITerraformIterator] = None,
    lifecycle: typing.Optional[typing.Union[_cdktn_78ede62e.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
    provider: typing.Optional[_cdktn_78ede62e.TerraformProvider] = None,
    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktn_78ede62e.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktn_78ede62e.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktn_78ede62e.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
    availability_zone_id: builtins.str,
    backup_subnet_cidr: builtins.str,
    client_subnet_cidr: builtins.str,
    display_name: builtins.str,
    s3_access: builtins.str,
    zero_etl_access: builtins.str,
    availability_zone: typing.Optional[builtins.str] = None,
    custom_domain_name: typing.Optional[builtins.str] = None,
    default_dns_prefix: typing.Optional[builtins.str] = None,
    delete_associated_resources: typing.Optional[typing.Union[builtins.bool, _cdktn_78ede62e.IResolvable]] = None,
    kms_access: typing.Optional[builtins.str] = None,
    kms_policy_document: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    s3_policy_document: typing.Optional[builtins.str] = None,
    sts_access: typing.Optional[builtins.str] = None,
    sts_policy_document: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    timeouts: typing.Optional[typing.Union[OdbNetworkTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0f8fe844b9d426d6706b7603202f9cd0a1aeb06aa46d4fb9aec355b882ee9b0(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bb63034bc4ec4c6f606b976205bce1f534cf8e7525eb7efbd1e1e39f4f21c23(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe6e8512faec34472dae1f2eec250936f00e9c85fe841c9c9c4c4b58253d5d74(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6036771eb0f1c258f39666cf937f96291264580b4ee1f9c86873bdbc3c9ca127(
    value: typing.Optional[OdbNetworkManagedServicesKmsAccess],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5706e05666772b09e5f6da86b26b1d3656ffc00559cd37da9e21290f98b8842c(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e2718494be95a06fc1239c348f55d3ae9f0bbbdf8f9f5424f9e87ad47b48465(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5812ba9bc673f27ab122b4a2681e01642952bd3ea097efe199eb974042134a0d(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2673d04c4966ce3366a3b9eba426a946c7c76382e7ae15251289a624de0e352(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0645d122aaa83139ef72772e01f1669021251b8088da2a2b0bcaad80ac4e3455(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc4c52c3dfe274548600a49873ca322adf03cb404d1fd0353f548e614f46810f(
    value: typing.Optional[OdbNetworkManagedServicesManagedS3BackupAccess],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0438c9e9ce7e30640609c34521c15a81a08d095514121ce321867b7b8e914a9f(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86f57cb1b9d0daefc51304897af84c972c89fa613fa7e9db43586546608af382(
    value: typing.Optional[OdbNetworkManagedServices],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44ae9530957cd38c5aad3696345e2237bffae5c09a4a3db2fa8167027cd05752(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a32a5497c528dc41f641d137e782452e5d7f107cda86c21563b9064d21f965e3(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8a7254f635a1a36f2e2b0cff7d88e8e0aa6279ec2d0c113deee930c15c226ff(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5153acbaf3f1a56b7ec27d0e16fb96380cfc76e4f807a40f1f94750c59b6bce1(
    value: typing.Optional[OdbNetworkManagedServicesS3Access],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdc08449d2e443bf17cf75eafb87b49006d202b4525736317cf6defcf55bf9e8(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51e0a683e39c640a670a66b8bfd106e12cbea61942f46da3576543dc27696a93(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c86bce760aa612c659fb42ab825fd75d5fe54799e8fa542f4b8c1cb530353a9c(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a084ca11b5b9c54f8cfa247d49d8d2e187899530ab85bd0bab6e4d680fc2b7f3(
    value: typing.Optional[OdbNetworkManagedServicesServiceNetworkEndpoint],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__218ce58ce6a0ba9ebe9a7656092ae7dcc852d081e5e31d8f47d700babe08e5d8(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c07e793d8b9e3908dc0b82f6ed60ca255f78d31dd757d68f5bbc8df9a4266e37(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d4bb4296f6e6b8d335bf5002d84e29b8769ef555ebd43aa94bda371e1030296(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__587c12f5d6d843ab1e38a37ba4c922f1aaeaefac6e3d2334f78f59da24e8d879(
    value: typing.Optional[OdbNetworkManagedServicesStsAccess],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a309c2e06280afee8635be58da30f280c7d8c168ab655e00f2889eb3835b95c(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2788ae580603a61faf0c4b3db940b8f692aa8263ebe06b1cc795406813a24e6a(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9796c044c5e03ff5f541f181bb35cba5f382660d5c6ff1a230fbcc600e2d859e(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71b3b323baf83c47836ac4782c15381cd7d90bd5b1d92007f9e33179eff4728b(
    value: typing.Optional[OdbNetworkManagedServicesZeroEtlAccess],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3626099940a40141b5d9b6b1b6c457b5497ca66458294152ef918d6020c4e059(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    wraps_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdd187780058177e6b99a64a557026a0c1279819bc2078dc968f100647023d97(
    index: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1d86cfee017b00d127461f9a37056b609bba04374ced72169a9c680ba3eb6c2(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
    complex_object_index: jsii.Number,
    complex_object_is_from_set: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6a6f4b55b79df4a3ab6840238444f8550cf2aaadef1172087b98794bfa2dfd7(
    value: typing.Optional[OdbNetworkOciDnsForwardingConfigs],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b560d33753cd3a01741250cfb15b84ffd6dfa3bdacaf9207d98bb2084367bcd(
    *,
    create: typing.Optional[builtins.str] = None,
    delete: typing.Optional[builtins.str] = None,
    update: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1da836746b31ff100061e40d2edc7109d70ad4efef9586fd8d7dfa6dc265eaa3(
    terraform_resource: _cdktn_78ede62e.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff9376bbe9afa03ce5e66e57d64875fde0a0923ed43471d9a2153b8614c73857(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a6a5abab89926e77d3a3508315e0289f7f098fd490cd94af16f56751954023d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__568b314af7d6583608ab871f1619555703a59a115b508a60d819ac7768889f96(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f7cd09015a39394a2ca3506e0307ddbc82e963dfa4c38a337033a8cdc122460(
    value: typing.Optional[typing.Union[_cdktn_78ede62e.IResolvable, OdbNetworkTimeouts]],
) -> None:
    """Type checking stubs"""
    pass
